@@ -33,7 +33,8 @@ class Mooter(RuntimeHook):
             self.http2.close()
         hooks = ServiceLoader.load(RuntimeHook).list('')
         for hook in hooks:
-            hook.refresh()
+            hook.stop()
 
     def refresh(self):
+        self.stop()
         self.start()
