@@ -13,7 +13,7 @@ class MeshException(RuntimeError, Codeable):
         self.message = message
 
     def __str__(self):
-        return f'{self.code}({self.message})'
+        return f'{self.code}, {self.message}'
 
     def get_code(self):
         return self.code
