@@ -44,8 +44,17 @@ class GrpcChannels:
         return conn(inbound, timeout, metadata, None, True, False)
 
     def stream(self, address: str, inbound: bytes, timeout: Any, metadata: Any) -> grpc.Future:
-        conn = self.create_stream(address)
-        return conn(inbound, timeout, metadata, None, True, False)
+        stream = self.create_stream(address)
+        return next(stream(inbound, timeout, metadata, None, True, False))
+
+
+class GrpcMultiplexStream:
+
+    def __int__(self, stream: grpc.StreamStreamMultiCallable):
+        self.stream = stream
+
+    def next(self, inbound: bytes) -> bytes:
+        return b''
 
 
 class GrpcMultiplexChannel(grpc.Channel):
