@@ -6,6 +6,7 @@
 from typing import Type, Any, Generic, Dict, List
 
 import mesh.kinds as kinds
+import mesh.log as log
 import mesh.tool as tool
 from mesh.kinds import Reference, Service, Environ, MeshFlag, Event, Registration, Resource, Topic, Versions
 from mesh.macro import T, mpi, MPI, spi, MPS, binding, Binding, ServiceLoader, Returns, Parameters, Inspector
@@ -311,7 +312,10 @@ class MeshEden(Eden, RuntimeHook, Subscriber):
         metadata = Resource()
         metadata.services = []
         metadata.references = []
-        self.registry().unregister(self.new_registration(metadata, {}))
+        try:
+            self.registry().unregister(self.new_registration(metadata, {}))
+        except BaseException as e:
+            log.warn("Graceful unregister metadata, {}", str(e))
 
     def refresh(self):
         self.start()
