@@ -4,7 +4,7 @@
 #
 #
 
-from typing import Dict, Any
+from typing import Dict, Any, Callable
 
 import mesh.log as log
 import mesh.tool as tool
@@ -24,12 +24,14 @@ class MeshTransport(Transport):
         self.sessions: Dict[str, Session] = dict()
 
     def open(self, session_id: str, metadata: Dict[str, str]) -> Session:
-        session = self.sessions.get(session_id, None)
+        skey = self.session_key(session_id, metadata)
+        session = self.sessions.get(skey, None)
         if not session:
             attachments = Mesh.context().get_attachments()
             addr = Mesh.context().get_attribute(Mesh.REMOTE)
             principal = Mesh.context().get_principals().peek()
-            session = self.sessions[session_id] = MeshSession(session_id, metadata, attachments, addr, principal)
+            session = MeshSession(session_id, metadata, attachments, addr, principal, lambda: self.finalize(skey))
+            self.sessions[skey] = session
         return session
 
     def close(self, timeout: int):
@@ -38,19 +40,34 @@ class MeshTransport(Transport):
                 v.release(timeout, "")
             except BaseException as e:
                 log.error("", e)
+        self.sessions.clear()
+
+    def roundtrip(self, payload: bytes, metadata: Dict[str, str]) -> bytes:
+        """ bid """
+        pass
+
+    def finalize(self, session_key: str):
+        self.sessions.__delitem__(session_key)
+
+    @staticmethod
+    def session_key(session_id: str, metadata: Dict[str, str]) -> str:
+        target_node_id = Metadata.MESH_TARGET_NODE_ID.get(metadata)
+        target_inst_id = Metadata.MESH_TARGET_INST_ID.get(metadata)
+        return f"{session_id}.{target_node_id}.{target_inst_id}"
 
 
 @spi("mesh")
 class MeshSession(Session):
 
     def __init__(self, session_id: str, metadata: Dict[str, str], attachments: Dict[str, str], address: str,
-                 principal: Principal):
+                 principal: Principal, finalizer: Callable):
         self.session_id = session_id
         self.metadata = metadata
         self.attachments = attachments
         self.address = address
         self.principal = principal
         self.session = ServiceProxy.default_proxy(Session)
+        self.finalizer = finalizer
 
     def with_context(self, fn: Any, remote: bool, timeout: int) -> Any:
         return Mesh.context_safe(lambda: self.context_safe(fn, remote, timeout))
@@ -97,5 +114,6 @@ class MeshSession(Session):
     def push(self, payload: bytes, metadata: Dict[str, str], topic: str = ""):
         return self.with_context(lambda: self.session.push(payload, metadata, topic), True, 0)
 
-    def release(self, timeout: int, topic: str):
+    def release(self, timeout: int, topic: str = ""):
+        self.finalizer()
         return self.with_context(lambda: self.session.release(timeout, topic), False, timeout)
